WebportingEngine
================

WebportingEngine merupakan framework yang dibangun untuk menampilkan halaman laporan JasperReport pada Java Servlet 3. WebportingEngine dibangun diatas Servlet 3, sehingga Anda tidak perlu menggunakan framework web apapun untuk menjalankan WebportingEngine.

##Instalasi WebportingEngine##

Instalasi WebportingEngine sangat sederhana, anda hanya perlu membuat kelas turunan `WebportingEngineListener` lalu menandainya sebagai @WebListener :

    @WebListener
    public class TestWebportingListener extends WebportingEngineListener {

        @Override
        public void registerCustomConverter(WebportingEngineConverter wec) {
            // register your custom converter
            // wec.registerConverter(ParamConverter, Class);
        }
    }

##Contoh Sederhana##

Setelah melakukan instalasi framework WebportingEngine, Anda dapat membuat halaman web servlet untuk menampilkan laporan JasperReport dengan membuat kelas turunan :

- [`WebportingEngine`](https://github.com/khannedy/WebportingEngine/blob/master/src/main/java/khannedy/webportingengine/engine/WebportingEngine.java) 
- [`AbstractWebportingEngine`](https://github.com/khannedy/WebportingEngine/blob/master/src/main/java/khannedy/webportingengine/engine/AbstractWebportingEngine.java) [Contoh](https://github.com/khannedy/WebportingEngine/wiki/SimpleAbstractWebportingEngine)
- [`AbstractParameterizeWebportingEngine`](https://github.com/khannedy/WebportingEngine/blob/master/src/main/java/khannedy/webportingengine/engine/AbstractParameterizeWebportingEngine.java) [Contoh](https://github.com/khannedy/WebportingEngine/wiki/SampleAbstractParameterizeWebportingEngine)
- [`AbstractReportWebportingEngine`](https://github.com/khannedy/WebportingEngine/blob/master/src/main/java/khannedy/webportingengine/engine/AbstractReportWebportingEngine.java)
- [`AbstractReportLocationWebportingEngine`](https://github.com/khannedy/WebportingEngine/blob/master/src/main/java/khannedy/webportingengine/engine/AbstractReportLocationWebportingEngine.java)
- [`AbstractDesignWebportingEngine`](https://github.com/khannedy/WebportingEngine/blob/master/src/main/java/khannedy/webportingengine/engine/AbstractDesignWebportingEngine.java)
- [`AbstractDesignLocationWebportingEngine`](https://github.com/khannedy/WebportingEngine/blob/master/src/main/java/khannedy/webportingengine/engine/AbstractDesignLocationWebportingEngine.java)

Disarankan untuk membuat kelas turunan kelas-kelas `Abstract*WebportingEngine`. Contoh sederhana adalah sebagai berikut :

Contoh kelas turunan `AbstractWebportingEngine` :

    @WebServlet(name = "LetterAngsuran", urlPatterns = {"/LetterAngsuran"})
    public class LetterAngsuran extends AbstractWebportingEngine {

        private static final long serialVersionUID = 1L;

        @Resource(name = "jdbc/rams-webapp")
        private DataSource dataSource;

        @Override
        public ReportType getReportType(ReportRequest request, ReportResponse response) throws ServletException, IOException {
            return ReportType.PDF;
        }

        @Override
        public void beforeProcess(ReportRequest request, ReportResponse response) throws ServletException, IOException {
            try {
                request.<Connection>setAttributeValue("CONNECTION", dataSource.getConnection());
            } catch (SQLException ex) {
                Logger.getLogger(LetterAngsuran.class.getName()).log(Level.SEVERE, null, ex);
            }
        }

        @Override
        public JasperPrint getJasperPrint(ReportRequest rr, ReportResponse rr1) throws ServletException, IOException, JRException {
            String paramAccNo = rr.<String>getParameter(String.class, "no");
            Connection connection = rr.<Connection>getAttributeValue("CONNECTION");

            Map<String, Object> map = new HashMap<String, Object>(0);
            map.put(JRParameter.REPORT_CONNECTION, connection);
            map.put("paramAccNo", paramAccNo);

            String file = "/com/unitytechno/rams/reporting/resource/letterAngsuran01.jrxml";
            JasperDesign design = WebportingLoaderHelper.loadDesign(file);
            JasperReport report = WebportingCompileHelper.compileDesign(design);

            JasperPrint print = JasperFillManager.fillReport(report, map);
            return print;
        }

        @Override
        public void afterProcess(ReportRequest request, ReportResponse response) throws ServletException, IOException {
            try {
                Connection connection = request.<Connection>getAttributeValue("CONNECTION");
                connection.close();
            } catch (SQLException ex) {
                Logger.getLogger(LetterAngsuran.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
    }

Dengan begitu, Anda dapat mengakses laporan tersebut melalui url http://localhost:8080/WebApp/LetterAngsuran?no=10106031