/*
 *  Copyright 2011 StripBandunk.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package com.stripbandunk.webporting.converter;

import javax.servlet.http.HttpServletRequest;
import com.stripbandunk.webporting.error.ParamConverterException;

/**
 *
 * @param <T> 
 * @author Eko Kurniawan Khannedy
 */
public abstract class AbstractParamConverter<T> implements ParamConverter<T> {

    private Class<T> paramClass;

    public AbstractParamConverter(Class<T> paramClass) {
        this.paramClass = paramClass;
    }

    @Override
    public Class<T> getParamClass() {
        return paramClass;
    }

    @Override
    public T convertParam(HttpServletRequest request, String key) {
        try {
            if (request.getParameter(key) == null) {
                return noParam(request, key);
            } else {
                return convert(request.getParameter(key));
            }
        } catch (Throwable t) {
            throw new ParamConverterException(t);
        }
    }

    public abstract T convert(String value) throws Throwable;
}
