/*
 *  Copyright 2011 StripBandunk.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package com.stripbandunk.webporting.converter;

import javax.servlet.http.HttpServletRequest;

/**
 * ParamConverter is super interface for all web parameter converter class
 * @param <T> 
 * @author Eko Kurniawan Khanendy
 * @since 1.0
 */
public interface ParamConverter<T> {

    /**
     * Get parameter class
     * @return #{@link Class} of T
     */
    Class<T> getParamClass();

    /**
     * Convert String parameter to T value
     * @param request #{@link HttpServletRequest}
     * @param key #{@link String} of param key
     * @return T value
     */
    T convertParam(HttpServletRequest request, String key);

    /**
     * Default value when no param with the key
     * @param request HttpServletRequest
     * @param key param key
     * @return default T value
     */
    T noParam(HttpServletRequest request, String key);
}
