/*
 *  Copyright 2011 StripBandunk.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package com.stripbandunk.webporting.engine;

import java.io.IOException;
import java.util.Map;
import javax.servlet.ServletException;
import com.stripbandunk.webporting.http.ReportRequest;
import com.stripbandunk.webporting.http.ReportResponse;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.JasperReport;

/**
 *
 * @author Eko Kurniawan Khannedy
 */
public abstract class AbstractReportWebportingEngine extends AbstractParameterizeWebportingEngine {

    private static final long serialVersionUID = 1L;

    public static final String DEFAULT_REPORT_TYPE_PARAMETER = "reporttype";

    @Override
    public String getReportTypeParameterName() {
        return AbstractReportWebportingEngine.DEFAULT_REPORT_TYPE_PARAMETER;
    }

    @Override
    public JasperPrint getJasperPrint(ReportRequest request, ReportResponse response) throws ServletException, IOException, JRException {
        Map<String, Object> map = getReportParameter(request, response);
        JasperReport report = getJasperReport(request, response);

        JasperPrint print = JasperFillManager.fillReport(report, map);
        return print;
    }

    public abstract Map<String, Object> getReportParameter(ReportRequest request, ReportResponse response) throws ServletException, IOException, JRException;

    public abstract JasperReport getJasperReport(ReportRequest request, ReportResponse response) throws ServletException, IOException, JRException;
}
