/*
 *  Copyright 2011 StripBandunk.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package com.stripbandunk.webporting.engine;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.net.URL;
import java.util.Date;
import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import com.stripbandunk.webporting.converter.impl.BigDecimalParamConverter;
import com.stripbandunk.webporting.converter.impl.BigIntegerParamConverter;
import com.stripbandunk.webporting.converter.impl.BooleanParamConverter;
import com.stripbandunk.webporting.converter.impl.ByteParamConverter;
import com.stripbandunk.webporting.converter.impl.CharacterParamConverter;
import com.stripbandunk.webporting.converter.impl.DateParamConverter;
import com.stripbandunk.webporting.converter.impl.DoubleParamConverter;
import com.stripbandunk.webporting.converter.impl.FloatParamConverter;
import com.stripbandunk.webporting.converter.impl.IntegerParamConverter;
import com.stripbandunk.webporting.converter.impl.LongParamConverter;
import com.stripbandunk.webporting.converter.impl.LowerStringParamConverter;
import com.stripbandunk.webporting.converter.impl.StringParamConverter;
import com.stripbandunk.webporting.converter.impl.URLParamConverter;
import com.stripbandunk.webporting.converter.impl.UpperStringParamConverter;
import com.stripbandunk.webporting.data.LowerString;
import com.stripbandunk.webporting.data.UpperString;

/**
 *
 * @author Eko Kurniawan Khannedy
 */
public abstract class WebportingEngineListener implements ServletContextListener, WebportingEngineConstant {

    private WebportingEngineConverter webportingConverter;

    @Override
    @SuppressWarnings("FinalMethod")
    public final void contextInitialized(ServletContextEvent sce) {
        // get context
        ServletContext context = sce.getServletContext();

        // register param converter
        webportingConverter = new WebportingEngineConverter();
        registerConverter(webportingConverter);
        context.setAttribute(WEBPORTING_CONVERTER, webportingConverter);

        // initialized engine
        engineInitialized(sce);
    }

    @Override
    @SuppressWarnings("FinalMethod")
    public final void contextDestroyed(ServletContextEvent sce) {
        ServletContext context = sce.getServletContext();

        // remove converter
        context.removeAttribute(WEBPORTING_CONVERTER);

        // destroy engine
        engineDestroyed(sce);
    }

    @SuppressWarnings("FinalMethod")
    public final void registerConverter(WebportingEngineConverter converter) {

        converter.<Long>registerConverter(new LongParamConverter());
        converter.<Integer>registerConverter(new IntegerParamConverter());
        converter.<Boolean>registerConverter(new BooleanParamConverter());
        converter.<Byte>registerConverter(new ByteParamConverter());
        converter.<Date>registerConverter(new DateParamConverter());
        converter.<Double>registerConverter(new DoubleParamConverter());
        converter.<Float>registerConverter(new FloatParamConverter());
        converter.<String>registerConverter(new StringParamConverter());
        converter.<URL>registerConverter(new URLParamConverter());
        converter.<Character>registerConverter(new CharacterParamConverter());
        converter.<BigDecimal>registerConverter(new BigDecimalParamConverter());
        converter.<BigInteger>registerConverter(new BigIntegerParamConverter());
        converter.<LowerString>registerConverter(new LowerStringParamConverter());
        converter.<UpperString>registerConverter(new UpperStringParamConverter());

        registerCustomConverter(converter);
    }

    public abstract void registerCustomConverter(WebportingEngineConverter converter);

    public abstract void engineInitialized(ServletContextEvent sce);

    public abstract void engineDestroyed(ServletContextEvent sce);
}
