/*
 *  Copyright 2011 StripBandunk.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package com.stripbandunk.webporting.helper;

import java.io.OutputStream;
import com.stripbandunk.webporting.type.ReportType;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JRExporter;
import net.sf.jasperreports.engine.JRExporterParameter;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.export.JRCsvExporter;
import net.sf.jasperreports.engine.export.JRHtmlExporter;
import net.sf.jasperreports.engine.export.JRPdfExporter;
import net.sf.jasperreports.engine.export.JRRtfExporter;
import net.sf.jasperreports.engine.export.JRTextExporter;
import net.sf.jasperreports.engine.export.JRXhtmlExporter;
import net.sf.jasperreports.engine.export.JRXlsExporter;
import net.sf.jasperreports.engine.export.JRXmlExporter;
import net.sf.jasperreports.engine.export.oasis.JROdsExporter;
import net.sf.jasperreports.engine.export.oasis.JROdtExporter;
import net.sf.jasperreports.engine.export.ooxml.JRDocxExporter;
import net.sf.jasperreports.engine.export.ooxml.JRPptxExporter;

/**
 *
 * @author Eko Kurniawan Khannedy
 */
@SuppressWarnings("FinalClass")
public final class WebportingExporterHelper {

    public static void export(JasperPrint print, ReportType type, OutputStream outputStream) throws JRException {
        if (type.equals(ReportType.CSV)) {
            WebportingExporterHelper.exportCsv(print, outputStream);
        } else if (type.equals(ReportType.DOCX)) {
            WebportingExporterHelper.exportDocx(print, outputStream);
        } else if (type.equals(ReportType.HTML)) {
            WebportingExporterHelper.exportHtml(print, outputStream);
        } else if (type.equals(ReportType.ODS)) {
            WebportingExporterHelper.exportOds(print, outputStream);
        } else if (type.equals(ReportType.ODT)) {
            WebportingExporterHelper.exportOdt(print, outputStream);
        } else if (type.equals(ReportType.PDF)) {
            WebportingExporterHelper.exportPdf(print, outputStream);
        } else if (type.equals(ReportType.PPT)) {
            WebportingExporterHelper.exportPpt(print, outputStream);
        } else if (type.equals(ReportType.RTF)) {
            WebportingExporterHelper.exportRtf(print, outputStream);
        } else if (type.equals(ReportType.TEXT)) {
            WebportingExporterHelper.exportText(print, outputStream);
        } else if (type.equals(ReportType.XHTML)) {
            WebportingExporterHelper.exportXhtml(print, outputStream);
        } else if (type.equals(ReportType.XLSX)) {
            WebportingExporterHelper.exportXlsx(print, outputStream);
        } else if (type.equals(ReportType.XML)) {
            WebportingExporterHelper.exportXml(print, outputStream);
        }
    }

    private WebportingExporterHelper() {
        // utility class
    }

    public static void exportPdf(JasperPrint print, OutputStream outputStream) throws JRException {
        JRPdfExporter exporter = new JRPdfExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportHtml(JasperPrint print, OutputStream outputStream) throws JRException {
        JRHtmlExporter exporter = new JRHtmlExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportXlsx(JasperPrint print, OutputStream outputStream) throws JRException {
        JRXlsExporter exporter = new JRXlsExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportDocx(JasperPrint print, OutputStream outputStream) throws JRException {
        JRDocxExporter exporter = new JRDocxExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportXml(JasperPrint print, OutputStream outputStream) throws JRException {
        JRXmlExporter exporter = new JRXmlExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportCsv(JasperPrint print, OutputStream outputStream) throws JRException {
        JRCsvExporter exporter = new JRCsvExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportOds(JasperPrint print, OutputStream outputStream) throws JRException {
        JROdsExporter exporter = new JROdsExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportOdt(JasperPrint print, OutputStream outputStream) throws JRException {
        JROdtExporter exporter = new JROdtExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportPpt(JasperPrint print, OutputStream outputStream) throws JRException {
        JRPptxExporter exporter = new JRPptxExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportRtf(JasperPrint print, OutputStream outputStream) throws JRException {
        JRRtfExporter exporter = new JRRtfExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportText(JasperPrint print, OutputStream outputStream) throws JRException {
        JRTextExporter exporter = new JRTextExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportXhtml(JasperPrint print, OutputStream outputStream) throws JRException {
        JRXhtmlExporter exporter = new JRXhtmlExporter();
        WebportingExporterHelper.exportReport(exporter, print, outputStream);
    }

    public static void exportReport(JRExporter exporter, JasperPrint print, OutputStream outputStream) throws JRException {
        exporter.setParameter(JRExporterParameter.JASPER_PRINT, print);
        exporter.setParameter(JRExporterParameter.OUTPUT_STREAM, outputStream);
        exporter.exportReport();
    }
}
