/*
 *  Copyright 2011 StripBandunk.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package com.stripbandunk.webporting.http;

import com.stripbandunk.webporting.converter.ParamConverter;
import com.stripbandunk.webporting.engine.WebportingEngineConverter;
import com.stripbandunk.webporting.helper.WebportingEngineHelper;
import java.util.Enumeration;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpSession;
import javax.servlet.http.HttpSessionContext;

/**
 *
 * @author Eko Kurniawan Khannedy
 */
public class ReportSession implements HttpSession {

    private HttpSession session;

    public ReportSession(HttpSession session) {
        this.session = session;
    }

    public <T> ParamConverter<T> getParamConverter(Class<T> paramClass) {
        return getWebportingEngineConverter().<T>getConverter(paramClass);
    }

    public WebportingEngineConverter getWebportingEngineConverter() {
        return WebportingEngineHelper.getWebportingEngineConverter(getServletContext());
    }

    @SuppressWarnings("unchecked")
    public <T> T getAttributeValue(String name) {
        return (T) session.getAttribute(name);
    }

    public <T> void setAttributeValue(String name, T value) {
        session.setAttribute(name, value);
    }

    public HttpSession getSession() {
        return session;
    }

    //<editor-fold defaultstate="collapsed" desc="HttpSession Method">
    @Override
    public void setMaxInactiveInterval(int interval) {
        session.setMaxInactiveInterval(interval);
    }

    @Override
    public void setAttribute(String name, Object value) {
        session.setAttribute(name, value);
    }

    /**
     *
     * @param name
     * @deprecated
     */
    @Override
    @SuppressWarnings("deprecation")
    public void removeValue(String name) {
        session.removeValue(name);
    }

    @Override
    public void removeAttribute(String name) {
        session.removeAttribute(name);
    }

    /**
     *
     * @param name
     * @param value
     * @deprecated
     */
    @Override
    @SuppressWarnings("deprecation")
    public void putValue(String name, Object value) {
        session.putValue(name, value);
    }

    @Override
    public boolean isNew() {
        return session.isNew();
    }

    @Override
    public void invalidate() {
        session.invalidate();
    }

    /**
     *
     * @return
     * @deprecated
     */
    @Override
    @SuppressWarnings("deprecation")
    public String[] getValueNames() {
        return session.getValueNames();
    }

    /**
     *
     * @param name
     * @return
     * @deprecated
     */
    @Override
    @SuppressWarnings("deprecation")
    public Object getValue(String name) {
        return session.getValue(name);
    }

    /**
     *
     * @return
     * @deprecated
     */
    @Override
    @SuppressWarnings("deprecation")
    public HttpSessionContext getSessionContext() {
        return session.getSessionContext();
    }

    @Override
    public ServletContext getServletContext() {
        return session.getServletContext();
    }

    @Override
    public int getMaxInactiveInterval() {
        return session.getMaxInactiveInterval();
    }

    @Override
    public long getLastAccessedTime() {
        return session.getLastAccessedTime();
    }

    @Override
    public String getId() {
        return session.getId();
    }

    @Override
    public long getCreationTime() {
        return session.getCreationTime();
    }

    @Override
    public Enumeration<String> getAttributeNames() {
        return session.getAttributeNames();
    }

    @Override
    public Object getAttribute(String name) {
        return session.getAttribute(name);
    }
    //</editor-fold>
}
