/*
 *  Copyright 2011 StripBandunk.
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package com.stripbandunk.webporting.type;

/**
 *
 * @author Eko Kurniawan Khannedy
 * @since 1.0
 */
public enum ReportType {

    /**
     * Portable Document Format 
     */
    PDF("application/pdf", "pdf"),
    /**
     * XHTML file
     */
    XHTML("application/xhtml+xml", "xhtml"),
    /**
     * Text file
     */
    TEXT("text/plain", "txt"),
    /**
     * Comma Separated Value
     */
    CSV("text/csv", "csv"),
    /**
     * HTML file
     */
    HTML("text/html", "html"),
    /**
     * Rich Text Format
     */
    RTF("application/rtf", "rtf"),
    /**
     * Microsoft Power Point
     */
    PPT("application/vnd.ms-powerpoint", "ppt"),
    /**
     * Microsoft Excel
     */
    XLSX("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet", "xlsx"),
    /**
     * XML file
     */
    XML("application/xml", "xml"),
    /**
     * Microsoft Word
     */
    DOCX("application/vnd.openxmlformats-officedocument.wordprocessingml.document", "docx"),
    /**
     * OpenDocument Text
     */
    ODT("application/vnd.oasis.opendocument.text", "odt"),
    /**
     * OpenDocument SpreadSheet
     */
    ODS("application/vnd.oasis.opendocument.spreadsheet", "ods");

    private String contentType;

    private String extention;

    private ReportType(String contentType, String extention) {
        this.contentType = contentType;
        this.extention = extention;
    }

    public String getExtention() {
        return extention;
    }

    public String getContentType() {
        return contentType;
    }

    @Override
    public String toString() {
        return getContentType();
    }
}
